#
# spec file for package bpython
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           bpython
Version:        0.12
Release:        17.12
Url:            http://www.bpython-interpreter.org
Summary:        Fancy Curses Interface to the Python Interactive Interpreter
License:        MIT
Group:          Development/Languages/Python
Source:         http://www.bpython-interpreter.org/releases/bpython-%{version}.tar.gz
Source1:        bpython-rpmlintrc
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  python-devel
BuildRequires:  python-setuptools
BuildRequires:  update-desktop-files
# Documentation requirements:
BuildRequires:  python-Sphinx
# Test requirements:
BuildRequires:  python-curses
BuildRequires:  python-mock
BuildRequires:  python-nose
Requires:       python-curses
Requires:       python-pygments
Requires:       python-pyparsing
Requires(post): update-alternatives
Requires(postun): update-alternatives
%if 0%{?suse_version} && 0%{?suse_version} <= 1110
%{!?python_sitelib: %global python_sitelib %(python -c "from distutils.sysconfig import get_python_lib; print get_python_lib()")}
%else
BuildArch:      noarch
%endif

%description
Bpython is an enhanced Python interactive interpreter that uses curses
and provides the following main features: in-line syntax highlighting;
readline-like autocompletion with suggestions displayed as you type; expected
argument specification for functions; a handy pastebin function to quickly
submit your code and return a URL. Its goal is to bring together a few handy
ideas to enhance the standard interpreter without getting carried away.

%prep
%setup -q
sed -i "/Icon.*/d" data/bpython.desktop # Drop non-existing icon reference
sed -i "s/bpython =/bpython-%{py_ver} =/" setup.py
sed -i "s/bpython-urwid =/bpython-urwid-%{py_ver} =/" setup.py
sed -i "s/bpython-gtk =/bpython-gtk-%{py_ver} =/" setup.py
sed -i "s/bpython.1/bpython-%{py_ver}.1/" setup.py
sed -i "s/bpython-config.5/bpython-config-%{py_ver}.5/" setup.py
sed -i "s/, 'bpython'/, 'bpython-%{py_ver}'/" doc/sphinx/source/conf.py
sed -i "s/, 'bpython-config'/, 'bpython-config-%{py_ver}'/" doc/sphinx/source/conf.py

%build
python setup.py build
python setup.py build_sphinx && rm build/sphinx/html/.buildinfo # HTML documentation

%install
python setup.py install --prefix=%{_prefix} --root=%{buildroot}
ln -s %{_bindir}/bpython-%{py_ver} %{buildroot}%{_bindir}/bpython
ln -s %{_bindir}/bpython-urwid-%{py_ver} %{buildroot}%{_bindir}/bpython-urwid
ln -s %{_bindir}/bpython-gtk-%{py_ver} %{buildroot}%{_bindir}/bpython-gtk
ln -s %{_mandir}/man1/bpython-%{py_ver}.1 %{buildroot}%{_mandir}/man1/bpython.1
ln -s %{_mandir}/man5/bpython-config-%{py_ver}.5 %{buildroot}%{_mandir}/man5/bpython-config.5
rm -r %{buildroot}%{python_sitelib}/bpython/test # Don't ship tests
%if 0%{?suse_version}
%suse_update_desktop_file -G bpython -r %{name} Development IDE
%endif

#NOTE(saschpe): Check the one failing test
#%%check
#nosetests

%pre
# Since /usr/bin/pybabel became ghosted to be used with update-alternatives, we have to get rid
# of the old binary resulting from the non-update-alternativies-ified package:
[ -h %{_bindir}/bpython ] || rm -f %{_bindir}/bpython
[ -h %{_bindir}/bpython-urwid ] || rm -f %{_bindir}/bpython-urwid
[ -h %{_bindir}/bpython-gtk ] || rm -f %{_bindir}/bpython-gtk
[ -h %{_mandir}/man1/bpython.1.gz ] || rm -f %{_mandir}/man1/bpython.1.gz
[ -h %{_mandir}/man5/bpython-config.5.gz ] || rm -f %{_mandir}/man5/bpython-config.5.gz

%post
update-alternatives \
    --install %{_bindir}/bpython bpython %{_bindir}/bpython-%{py_ver} 30 \
    --slave %{_bindir}/bpython-urwid bpython-urwid %{_bindir}/bpython-urwid-%{py_ver} \
    --slave %{_bindir}/bpython-gtk bpython-gtk %{_bindir}/bpython-gtk-%{py_ver} \
    --slave %{_mandir}/man1/bpython.1.gz bpython.1 %{_mandir}/man1/bpython-%{py_ver}.1.gz \
    --slave %{_mandir}/man5/bpython-config.5.gz bpython-config.5 %{_mandir}/man5/bpython-config-%{py_ver}.5.gz

%preun
if [ $1 -eq 0 ] ; then
    update-alternatives --remove bpython %{_bindir}/bpython-%{py_ver}
fi

%files
%defattr(-,root,root)
%doc AUTHORS CHANGELOG LICENSE ROADMAP TODO build/sphinx/html
%ghost %{_bindir}/bpython
%{_bindir}/bpython-%{py_ver}
%ghost %{_bindir}/bpython-gtk
%{_bindir}/bpython-gtk-%{py_ver}
%ghost %{_bindir}/bpython-urwid
%{_bindir}/bpython-urwid-%{py_ver}
%{python_sitelib}/bpdb
%{python_sitelib}/bpython-%{version}-py%{py_ver}.egg-info
%{python_sitelib}/bpython
%ghost %{_mandir}/man1/bpython.1.gz
%{_mandir}/man1/bpython-%{py_ver}.1.gz
%ghost %{_mandir}/man5/bpython-config.5.gz
%{_mandir}/man5/bpython-config-%{py_ver}.5.gz
%{_datadir}/applications/%{name}.desktop

%changelog
* Sat Nov  8 2014 Led <ledest@gmail.com>
- fix bashisms in pre script
* Thu Jul 31 2014 dimstar@opensuse.org
- Rename rpmlintrc to %%{name}-rpmlintrc.
  Follow the packaging guidelines.
* Fri Oct 11 2013 p.drouand@gmail.com
- Slave -urwid and -gtk to bpython binary instead of install it with
  update-alternatives
* Mon Oct  7 2013 p.drouand@gmail.com
- Apply update-alternatives for binaries and man-pages
* Thu Mar 21 2013 speilicke@suse.com
- Drop bpython.desktop, instead only use suse_update_desktop_file
  to fix up the upstream one
- Build and install HTML documentation
* Mon Jan  7 2013 p.drouand@gmail.com
- Update to 0.12 version:
  * Added a new pastebin_helper config option to name an executable that should
  perform pastebin upload on bpython's behalf. If set, this overrides
  pastebin_url. Data is supplied to the helper via STDIN, and it is expected
  to return a pastebin URL as the first word of its output.
  * Fixed a bug causing pastebin upload to fail after a previous attempt was
  unsuccessful. A duplicate pastebin error would be displayed in this case,
  despite the original upload having failed.
  * Added more key shortcuts to bpython.urwid
  * Smarter dedenting after certain expressions
  * #74 fixed broken completion when auto_display_list was disabled
- Add python-Sphinx as a build dependencie since man doc building from source
* Tue Jun 26 2012 saschpe@suse.de
- Update to version 0.11:
  + #204: "import math" not autocompleting on python 3.2
* Fri Sep  2 2011 saschpe@suse.de
- Update to version 0.10.1:
  + #197: find_modules crashes on non-readable directories
  + #198: Source tarball lacks .po files
- Changes from version 0.10:
  + Config files are now located according to the XDG Base Directory
    Specification. The support for the old bpythonrc files has been
    dropped and ~/.bpython.ini as config file location is no longer supported.
    See issue #91.
  + Fixed some issues with tuple unpacking in argspec. See issues #133 and #138.
  + Fixed a crash with non-ascii filenames in import completion. See issue #139.
  + Fixed a crash caused by inspect.findsource() raising an IndexError
    which happens in some situations. See issue #94.
  + Non-ascii input should work now under Python 3.
  + Issue #165: C-a and C-e do the right thing now in urwid.
  + The short command-line option "-c config" was dropped as it conflicts with
    vanilla Python's "-c command" option. See issue #186.
* Sun Jul  3 2011 saschpe@gmx.de
- Cleaned up spec file:
  * Removed 'python' dependency, have python-devel
  * Require python-pyparsing instead of python-parsing
  * Removed scripting madness and use proper SUSE version checks
  * Addded AUTHORS, ROADMAP and TODO doc files
* Fri May 13 2011 pth@suse.de
- Add missing requires for python-curses (bnc#693545).
* Tue Aug  3 2010 pascal.bleser@opensuse.org
- update to 0.9.7.1:
  * new features:
    + pastebin confirmation
    + ability to ignore PYTHONSTARTUP when launched with -i
    + addition of bpdb (bpython python debugger)
    + correct operation of C-w
    + a more comprehensive unit testing suite
    + pastebin deduplication
    + import completion improvements
    + GTK improvements
  * bug fixes
* Thu Dec 31 2009 pascal.bleser@opensuse.org
- update to 0.9.6.2:
  * fixes Python 3 compatibility
* Thu Dec 31 2009 pascal.bleser@opensuse.org
- update to 0.9.6.1:
  * a crash in the "Save" functionality was fixed
* Wed Dec 30 2009 pascal.bleser@opensuse.org
- update to 0.9.6:
  * numerous minor bugs were fixed
  * features were implemented to make general usage a lot smoother
  * a showcase of beta GTK support was added
* Wed Sep 30 2009 pascal.bleser@opensuse.org
- update to 0.9.5.2:
  * filename expansion was fixed
  * future imports now work
  * docstring fixes were made for types with their own __init__ method
* Tue Sep 22 2009 pascal.bleser@opensuse.org
- update to 0.9.5.1:
  * various bugfixes
  * introspect on Python functions' source code
  * initial Python 3.x support
  * miscellaneous configuration improvements
* Thu Jul 23 2009 pascal.bleser@opensuse.org
- update to 0.9.4:
  * bugfix release
  * a few extra enhancements to parenthesis highlighting and extended key configurability
  * tab completion for filenames when inside a string
* Wed Jun 17 2009 pascal.bleser@opensuse.org
- update to 0.9.3
* Mon Jun  1 2009 pascal.bleser@opensuse.org
- update to 0.9.0:
  * import completion was added
  * paste.pocoo.org is now used for pastebin
  * a color scheme that works well with a white background was added
  * general bugfixes and improvements were made
* Mon Aug 25 2008 guru@unixtech.be
- update to 0.7.0:
  * bugfixes
  * fixed handling of home/end/del etc. properly
  * raw_input() and friends now work correctly
  * fixed parsing PYTHONSTARTUP
  * adds manpages
* Sat Jun 28 2008 guru@unixtech.be
- new upstream version
* Sat Jun 14 2008 guru@unixtech.be
- new upstream version:
  * code cleanups
  * fixed several bugs that could cause bpython to crash due to autocompletion drama
  * properly returns control to the terminal on the event of a traceback
* Sun Apr 27 2008 guru@unixtech.be
- removed patch, was merged upstream
- new upstream version
* Sat Apr 26 2008 guru@unixtech.be
- new package
